/*
 ## Cypress USB 3.0 Platform source file (cyfxuvcdscr.c)
 ## ===========================
 ##
 ##  Copyright Cypress Semiconductor Corporation, 2010-2011,
 ##  All Rights Reserved
 ##  UNPUBLISHED, LICENSED SOFTWARE.
 ##
 ##  CONFIDENTIAL AND PROPRIETARY INFORMATION
 ##  WHICH IS THE PROPERTY OF CYPRESS.
 ##
 ##  Use of this file is governed
 ##  by the license agreement included in the file
 ##
 ##     <install>/license/license.txt
 ##
 ##  where <install> is the Cypress software
 ##  installation root directory path.
 ##
 ## ===========================
 */

/* This file contains the USB enumeration descriptors for the UVC (in memory) application example.
 * The descriptor arrays must be 32 byte aligned and multiple of 32 bytes if the D-cache is
 * turned on. If the linker used is not capable of supporting the aligned feature for this,
 * either the descriptors must be placed in a different section and the section should be 
 * 32 byte aligned and 32 byte multiple; or dynamically allocated buffer allocated using
 * CyU3PDmaBufferAlloc must be used, and the descriptor must be loaded into it. The example
 * assumes that the aligned attribute for 32 bytes is supported by the linker. Do not add
 * any other variables to this file other than USB descriptors. This is not the only
 * pre-requisite to enabling the D-cache. Refer to the documentation for
 * CyU3PDeviceCacheControl for more information.
 */

#include "cyfxuvcinmem.h"

#define ES_UVC_INTRFC_ASSN_DESCR                (11)            /* Interface association descriptor type. */

/* Standard device descriptor for USB 3.0 */
const uint8_t CyFxUSB30DeviceDscr[] __attribute__ ((aligned (32))) =
{
		0x12,                           /* Descriptor size */
		CY_U3P_USB_DEVICE_DESCR,        /* Device descriptor type */
		0x00,0x03,                      /* USB 3.0 */
		0xEF,                           /* Device class */
		0x02,                           /* Device Sub-class */
		0x01,                           /* Device protocol */
		0x09,                           /* Maxpacket size for EP0 : 2^9 */
		0xB4,0x04,                      /* Vendor ID */
		0x22,0x47,                      /* Product ID */
		0x00,0x00,                      /* Device release number */
		0x01,                           /* Manufacture string index */
		0x02,                           /* Product string index */
		0x00,                           /* Serial number string index */
		0x01                            /* Number of configurations */
};

/* Standard device descriptor */
const uint8_t CyFxUSB20DeviceDscr[] __attribute__ ((aligned (32))) =
{
		0x12,                           /* Descriptor size */
		CY_U3P_USB_DEVICE_DESCR,        /* Device descriptor type */
		0x10,0x02,                      /* USB 2.10 */
		0x00,                           /* Device class */
		0x00,                           /* Device sub-class */
		0x00,                           /* Device protocol */
		0x40,                           /* Maxpacket size for EP0 : 64 bytes */
		0x8C,0x0D,                      /* Vendor ID */
		0x3c,0x01,                      /* Product ID */
		0x00,0x01,                      /* Device release number */
		0x02,                           /* Manufacture string index */
		0x02,                           /* Product string index */
		0x01,                           /* Serial number string index */
		0x01                            /* Number of configurations */
};

/* Binary device object store descriptor */
const uint8_t CyFxUSBBOSDscr[] __attribute__ ((aligned (32))) =
{
		0x05,                           /* Descriptor size */
		CY_U3P_BOS_DESCR,               /* Device descriptor type */
		0x16,0x00,                      /* Length of this descriptor and all sub descriptors */
		0x02,                           /* Number of device capability descriptors */

		/* USB 2.0 Extension */
		0x07,                           /* Descriptor size */
		CY_U3P_DEVICE_CAPB_DESCR,       /* Device capability type descriptor */
		CY_U3P_USB2_EXTN_CAPB_TYPE,     /* USB 2.0 extension capability type */
		0x02,0x00,0x00,0x00,            /* Supported device level features: LPM support  */

		/* SuperSpeed Device Capability */
		0x0A,                           /* Descriptor size */
		CY_U3P_DEVICE_CAPB_DESCR,       /* Device capability type descriptor */
		CY_U3P_SS_USB_CAPB_TYPE,        /* SuperSpeed device capability type */
		0x00,                           /* Supported device level features  */
		0x0E,0x00,                      /* Speeds supported by the device : SS, HS and FS */
		0x03,                           /* Functionality support */
		0x00,                           /* U1 device exit latency */
		0x00,0x00                       /* U2 device exit latency */
};

/* Standard device qualifier descriptor */
const uint8_t CyFxUSBDeviceQualDscr[] __attribute__ ((aligned (32))) =
{
		0x0A,                           /* descriptor size */
		CY_U3P_USB_DEVQUAL_DESCR,       /* Device qualifier descriptor type */
		0x10,0x02,                      /* USB 2.0 */
		0x00,                           /* Device class */
		0x00,                           /* Device sub-class */
		0x00,                           /* Device protocol */
		0x40,                           /* Maxpacket size for EP0 : 64 bytes */
		0x01,                           /* Number of configurations */
		0x00                            /* Reserved */
};

/* Standard super speed configuration descriptor */
const uint8_t CyFxUSBSSConfigDscr[] __attribute__ ((aligned (32))) =
{
		/* Configuration descriptor */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_CONFIG_DESCR,        /* Configuration descriptor type */
		0xD2,0x00,                      /* Length of this descriptor and all sub descriptors */
		0x02,                           /* Number of interfaces */
		0x01,                           /* Configuration number */
		0x00,                           /* COnfiguration string index */
		0x80,                           /* Config characteristics - Bus powered */
		0x32,                           /* Max power consumption of device (in 8mA unit) : 400mA */

		/* Interface association descriptor */
		0x08,                           /* Descriptor size */
		CY_FX_INTF_ASSN_DSCR_TYPE,      /* Interface association descr type */
		0x00,                           /* I/f number of first VideoControl i/f */
		0x02,                           /* Number of video streaming i/f */
		0x0E,                           /* CC_VIDEO : Video i/f class code */
		0x03,                           /* SC_VIDEO_INTERFACE_COLLECTION : Subclass code */
		0x00,                           /* Protocol : Not used */
		0x00,                           /* String desc index for interface */

		/* Standard video control interface descriptor */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		0x00,                           /* Interface number */
		0x00,                           /* Alternate setting number */
		0x01,                           /* Number of end points */
		0x0E,                           /* CC_VIDEO : Interface class */
		0x01,                           /* CC_VIDEOCONTROL : Interface sub class */
		0x00,                           /* Interface protocol code */
		0x00,                           /* Interface descriptor string index */

		/* Class specific VC interface header descriptor */
		0x0D,                           /* Descriptor size */
		0x24,                           /* Class specific i/f header descriptor type */
		0x01,                           /* Descriptor sub type : VC_HEADER */
		0x00,0x01,                      /* Revision of class spec : 1.0 */
		0x50,0x00,                      /* Total size of class specific descriptors (till output terminal) */
		0x00,0x6C,0xDC,0x02,            /* Clock frequency : 48MHz */
		0x01,                           /* Number of streaming interfaces */
		0x01,                           /* Video streaming i/f 1 belongs to VC i/f */

		/* Input (camera) terminal descriptor */
		0x12,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x02,                           /* Input Terminal Descriptor type */
		0x01,                           /* ID of this terminal */
		0x01,0x02,                      /* Camera terminal type */
		0x00,                           /* No association terminal */
		0x00,                           /* String desc index : Not used */
		0x00,0x00,                      /* No optical zoom supported */
		0x00,0x00,                      /* No optical zoom supported */
		0x00,0x00,                      /* No optical zoom supported */
		0x03,                           /* Size of controls field for this terminal : 3 bytes */
		0x00,0x00,0x00,                 /* No controls supported */

		/* Processing unit descriptor */
		0x0C,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x05,                           /* Processing unit descriptor type */
		0x02,                           /* ID of this terminal */
		0x01,                           /* Source ID : 1 : conencted to input terminal */
		0x00,0x40,                      /* Digital multiplier */
		0x03,                           /* Size of controls field for this terminal : 3 bytes */
		0x00,0x00,0x00,                 /* No controls supported */
		0x00,                           /* String desc index : Not used */

		/* Extension unit descriptor */
		0x1C,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x06,                           /* Extension unit descriptor type */
		0x03,                           /* ID of this terminal */
		0xFF,0xFF,0xFF,0xFF,            /* 16 byte GUID */
		0xFF,0xFF,0xFF,0xFF,
		0xFF,0xFF,0xFF,0xFF,
		0xFF,0xFF,0xFF,0xFF,
		0x00,                           /* Number of controls in this terminal */
		0x01,                           /* Number of input pins in this terminal */
		0x02,                           /* Source ID : 2 : connected to proc unit */
		0x03,                           /* Size of controls field for this terminal : 3 bytes */
		0x00,0x00,0x00,                 /* No controls supported */
		0x00,                           /* String desc index : Not used */

		/* Output terminal descriptor */
		0x09,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x03,                           /* Output terminal descriptor type */
		0x04,                           /* ID of this terminal */
		0x01,0x01,                      /* USB streaming terminal type */
		0x00,                           /* No association terminal */
		0x03,                           /* Source ID : 3 : Connected to extn Unit */
		0x00,                           /* String desc index : Not used */

		/* Video control status interrupt endpoint descriptor */
		0x07,                           /* Descriptor size */
		CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
		CY_FX_EP_CONTROL_STATUS,        /* Endpoint address and description */
		CY_U3P_USB_EP_INTR,             /* Interrupt end point type */
		0x40,0x00,                      /* Max packet size = 64 bytes */
		0x01,                           /* Servicing interval */

		/* Super speed endpoint companion descriptor */
		0x06,                           /* Descriptor size */
		CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
		0x00,                           /* Max no. of packets in a Burst : 1 */
		0x00,                           /* Mult.: Max number of packets : 1 */
		0x40,0x00,                      /* Bytes per interval : 64 */

		/* Class specific interrupt endpoint descriptor */
		0x05,                           /* Descriptor size */
		0x25,                           /* Class specific endpoint descriptor type */
		CY_U3P_USB_EP_INTR,             /* End point sub type */
		0x40,0x00,                      /* Max packet size = 64 */

		/* Standard video streaming interface descriptor (Alternate setting 0) */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		0x01,                           /* Interface number */
		0x00,                           /* Alternate setting number */
		0x00,                           /* Number of end points : zero bandwidth */
		0x0E,                           /* Interface class : CC_VIDEO */
		0x02,                           /* Interface sub class : CC_VIDEOSTREAMING */
		0x00,                           /* Interface protocol code : Undefined */
		0x00,                           /* Interface descriptor string index */

		/* Class-specific video streaming input header descriptor */
		0x0E,                           /* Descriptor size */
		0x24,                           /* Class-specific VS i/f Type */
		0x01,                           /* Descriptotor subtype : input header */
		0x01,                           /* 1 format desciptor follows */
		0x19,0x00,                      /* Total size of class specific VS descr */
		CY_FX_EP_ISO_VIDEO,             /* EP address for ISO video data */
		0x00,                           /* No dynamic format change supported */
		0x04,                           /* Output terminal ID : 4 */
		0x01,                           /* Still image capture method 1 supported */
		0x01,                           /* Hardware trigger supported for still image */
		0x00,                           /* Hardware to initiate still image capture */
		0x01,                           /* Size of controls field : 1 byte */
		0x00,                           /* D2 : Compression quality supported */

		/* Class specific VS format descriptor */
		0x0B,                           /* Descriptor size */
		0x24,                           /* Class-specific VS i/f type */
		0x06,                           /* Descriptotor subtype : VS_FORMAT_MJPEG */
		0x01,                           /* Format desciptor index */
		0x01,                           /* 1 Frame desciptor follows */
		0x01,                           /* Uses fixed size samples */
		0x01,                           /* Default frame index is 1 */
		0x00,                           /* Non interlaced stream not reqd. */
		0x00,                           /* Non interlaced stream not reqd. */
		0x00,                           /* Non interlaced stream */
		0x00,                           /* CopyProtect: duplication unrestricted */

		/* Class specific VS frame descriptor */
		0x1E,                           /* Descriptor size */
		0x24,                           /* Class-specific VS i/f type */
		0x07,                           /* Descriptotor Subtype : VS_FRAME_MJPEG */
		0x01,                           /* Frame desciptor index */
		0x00,                           /* Still image capture method not supported */
		0xB0,0x00,                      /* Width of the frame : 176 */
		0x90,0x00,                      /* Height of the frame : 144 */
		0x00,0xC0,0x5D,0x00,            /* Min bit rate bits/s */
		0x00,0xC0,0x5D,0x00,            /* Max bit rate bits/s */
		0x00,0x58,0x02,0x00,            /* Maximum video or still frame size in bytes */
		0x2A,0x2C,0x0A,0x00,            /* Default frame interval */
		0x01,                           /* Frame interval type : No of discrete intervals */
		0x2A,0x2C,0x0A,0x00,            /* Frame interval 3 */

		/* Standard video streaming interface descriptor (Alternate setting 1) */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		0x01,                           /* Interface number */
		0x01,                           /* Alternate setting number */
		0x01,                           /* Number of end points : 1 ISO EP */
		0x0E,                           /* Interface class : CC_VIDEO */
		0x02,                           /* Interface sub class : CC_VIDEOSTREAMING */
		0x00,                           /* Interface protocol code : Undefined */
		0x00,                           /* Interface descriptor string index */

		/* Endpoint descriptor for ISO streaming video data */
		0x07,                           /* Descriptor size */
		CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
		CY_FX_EP_ISO_VIDEO,             /* Endpoint address and description */
		CY_U3P_USB_EP_ISO,              /* ISO end point : Async */
		0x00,
		0x04,                           /* Max packet size is 1024 bytes. */
		0x01,                           /* Servicing interval for data transfers */

		/* Super speed endpoint companion descriptor */
		0x06,                           /* Descriptor size */
		CY_U3P_SS_EP_COMPN_DESCR,       /* SS endpoint companion descriptor type */
		CY_FX_EP_ISO_VIDEO_SS_BURST - 1,/* Max no. of packets in a burst */
		CY_FX_EP_ISO_VIDEO_SS_MULT - 1, /* Mult setting: Number of bursts per service interval. */
		0x00, 0x04 * CY_FX_EP_ISO_VIDEO_PKTS_COUNT	/* Bytes per interval : 1024 */

};


/* Standard High Speed Configuration Descriptor */
const uint8_t CyFxUSBHSConfigDscr4[] __attribute__ ((aligned (32))) =
{
	/* Configuration descriptor */
	0x09,                           /* Descriptor size */
	CY_U3P_USB_CONFIG_DESCR,        /* Configuration descriptor type */
	//0x64, 0x00,                   /* Length of this descriptor and all sub descriptors */
	0xBF, 0x00,
	0x04,                           /* Number of interfaces */
	0x01,                           /* Configuration number */
	0x00,                           /* Configuration string index */
	0x80,                           /* Config characteristics - bus powered */
	0x32,                           /* Max power consumption of device (in 2mA unit) : 100mA */

	/* Standard Audio Control Interface Descriptor */
	0x09,                           /* Descriptor Size */
	CY_U3P_USB_INTRFC_DESCR,		/* Interface Descriptor Type */
	0x00,                           /* Interface number */
	0x00,                           /* Alternate setting */
	0x00,                           /* Number of endpoints - 0 endpoints */
	0x01,                           /* Interface Class - Audio */
	0x01,                           /* Interface SubClass - Audio Control */
	0x00,                           /* Interface Protocol - Unused */
	0x00,                           /* Interface string index */

	/* Class Specific Audio Control Interface Descriptor */
	0x09,                           /* Descriptor Size */
	0x24,                           /* Descriptor Type - CS_INTERFACE */
	0x01,                           /* Descriptor SubType - Header */
	0x00, 0x01,                     /* Revision of class specification - 1.0 */
	0x1E, 0x00,                     /* Total size of class specific descriptors */
	0x01,                           /* Number of streaming Interfaces - 1 */
	0x01,                           /* Audio Streaming interface 1 belongs to this AudioControl Interface */

	/* Input terminal descriptor */
	0x0C,                           /* Descriptor size in bytes */
	0x24,                           /* CS Interface Descriptor */
	0x02,                           /* Input Terminal Descriptor subtype */
	0x01,                           /* ID Of the input terminal */
	0x01, 0x01,                     /* USB Streaming - terminal type */
	0x00,                           /* Association terminal - None */
	0x02,                           /* Number of channels - 2 */
	0x03, 0x00,                     /* spatial location of the logical channels - Front Left and Front Right */
	0x00,                           /* Channel names - Unused */
	0x00,                           /* String index for this descriptor - None */

	/* Output terminal descriptor */
	0x09,                           /* Descriptor size */
	0x24,                           /* Class specific interface desc type */
	0x03,                           /* Output terminal descriptor type */
	0x02,                           /* ID of this terminal */
	0x01, 0x03,                     /* Output terminal type: Speaker */
	0x00,                           /* Association terminal - Unused */
	0x01,                           /* Id of the terminal/unit to which this is connected - Input terminal id */
	0x00,                           /* String desc index : Not used */

	/* Standard Audio Streaming Interface Descriptor (Alternate setting 0) */
	0x09,                           /* Descriptor size */
	CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
	0x01,                           /* Interface number */
	0x00,                           /* Alternate setting number */
	0x00,                           /* Number of end points : zero bandwidth */
	0x01,                           /* Interface class : Audio */
	0x02,                           /* Interface sub class : Audio Streaming */
	0x00,                           /* Interface protocol code : Unused */
	0x00,                           /* Interface descriptor string index */

	/* Standard Audio Streaming Interface descriptor (Alternate setting 1) */
	0x09,                           /* Descriptor size */
	CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
	0x01,                           /* Interface number */
	0x01,                           /* Alternate setting number */
	0x01,                           /* Number of end points : 1 ISO EP */
	0x01,                           /* Interface Audio class */
	0x02,                           /* Interface Audio sub class - Audio Streaming */
	0x00,                           /* Interface protocol code : Unused */
	0x00,                           /* Interface descriptor string index */

	/* Class-specific Audio Streaming General Interface descriptor */
	0x07,                           /* Descriptor size */
	0x24,                           /* Class-specific AS i/f Type */
	0x01,                           /* Descriptotor subtype : AS General */
	0x01,                           /* Terminal Link - input terminal id */
	0x01,                           /* Interface delay */
	0x01, 0x00,                     /* Audio data format - PCM */

	/* Class specific AS Format descriptor - Type I Format Descriptor */
	0x0B,                           /* Descriptor size */
	0x24,                           /* Class-specific Interface Descriptor Type */
	0x02,                           /* Format Type Descriptor subtype */
	0x01,                           /* PCM FORMAT_TYPE_I */
	0x02,                           /* Number of channels - 2 */
	0x03,                           /* Subframe size - 8 bytes per audio subframe */
	0x18,                           /* Bit resolution - 24 bits */
	0x01,                           /* Number of samping frequencies - 1 */
	0x80, 0xBB, 0x00,               /* Sampling frequency - 48kHz */

	/* Endpoint descriptor for ISO streaming Audio data */
	0x09,                           /* Descriptor size */
	CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
	0x01,							/* Endpoint address and description */
	CY_U3P_USB_EP_ISO ,				/* ISO End point : Async */
	0xD0, 0x02,						/* Transaction size - 3*2*49 bytes per frame */
	0x03,                           /* Servicing interval for data transfers */
	0x00,							/* bRefresh */
	0x00,							/* bSynchAddress */

	/* Class Specific AS Isochronous Audio Data Endpoint Descriptor */
	0x07,                           /* Descriptor size in bytes */
	0x25,                           /* CS_ENDPOINT descriptor type */
	0x01,                           /* EP_GENERAL sub-descriptor type */
	0x00,                           /* bmAttributes - Max packets only */
	0x00,                           /* bLockDelayUnits - Unused */
	0x00, 0x00,                     /* wLockDelay - unused */


#if 1
	/*Total = 0x5B*/
	/* Standard Audio Control Interface Descriptor */
	0x09,                           /* Descriptor Size */
	0x04,                           /* Interface Descriptor Type */
	0x02,                           /* Interface number */
	0x00,                           /* Alternate setting */
	0x00,                           /* Number of endpoints - 0 endpoints */
	0x01,                           /* Interface Class - Audio */
	0x01,                           /* Interface SubClass - Audio Control */
	0x00,                           /* Interface Protocol - Unused */
	0x00,                           /* Interface string index */

	/* Class Specific Audio Control Interface Descriptor */
	0x09,                           /* Descriptor Size */
	0x24,                           /* Descriptor Type - CS_INTERFACE */
	0x01,                           /* Descriptor SubType - Header */
	0x00, 0x01,                     /* Revision of class specification - 1.0 */
	0x1E, 0x00,                     /* Total size of class specific descriptors */
	0x01,                           /* Number of streaming Interfaces - 1 */
	0x03,                           /* Audio Streaming interface 3 belongs to this AudioControl Interface */

	/* Input terminal descriptor */
	0x0C,                           /* Descriptor size in bytes */
	0x24,                           /* CS Interface Descriptor */
	0x02,                           /* Input Terminal Descriptor subtype */
	0x03,                           /* ID Of the input terminal */
	0x01, 0x02,                     /* Microphone - terminal type */
	0x00,                           /* Association terminal - None */
	0x02,                           /* Number of channels - 2 */
	0x03, 0x00,                     /* spatial location of the logical channels - Front Left and Front Right */
	0x00,                           /* Channel names - Unused */
	0x00,                           /* String index for this descriptor - None */

	/* Output terminal descriptor */
	0x09,                           /* Descriptor size */
	0x24,                           /* Class specific interface desc type */
	0x03,                           /* Output terminal descriptor type */
	0x04,                           /* ID of this terminal */
	0x01, 0x01,                     /* Output terminal type: USB Streaming */
	0x00,                           /* Association terminal - Unused */
	0x03,                           /* Id of the terminal/unit to which this is connected - Input terminal id */
	0x00,                           /* String desc index : Not used */

	/* Standard Audio Streaming Interface Descriptor (Alternate setting 0) */
	0x09,                           /* Descriptor size */
	CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
	0x03,                           /* Interface number */
	0x00,                           /* Alternate setting number */
	0x00,                           /* Number of end points : zero bandwidth */
	0x01,                           /* Interface class : Audio */
	0x02,                           /* Interface sub class : Audio Streaming */
	0x00,                           /* Interface protocol code : Unused */
	0x00,                           /* Interface descriptor string index */

	/* Standard Audio Streaming Interface descriptor (Alternate setting 1) */
	0x09,                           /* Descriptor size */
	CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
	0x03,                           /* Interface number */
	0x01,                           /* Alternate setting number */
	0x01,                           /* Number of end points : 1 ISO EP */
	0x01,                           /* Interface Audio class */
	0x02,                           /* Interface Audio sub class - Audio Streaming */
	0x00,                           /* Interface protocol code : Unused */
	0x00,                           /* Interface descriptor string index */

	/* Class-specific Audio Streaming General Interface descriptor */
	0x07,                           /* Descriptor size */
	0x24,                           /* Class-specific AS i/f Type */
	0x01,                           /* Descriptotor subtype : AS General */
	0x04,                           /* Terminal Link - Output terminal id */
	0x01,                           /* Interface delay */
	0x01, 0x00,                     /* Audio data format - PCM */

	/* Class specific AS Format descriptor - Type I Format Descriptor */
	0x0B,                           /* Descriptor size */
	0x24,                           /* Class-specific Interface Descriptor Type */
	0x02,                           /* Format Type Descriptor subtype */
	0x01,                           /* PCM FORMAT_TYPE_I */
	0x02,                           /* Number of channels - 2 */
	0x02,                           /* Subframe size - 2 bytes per audio subframe */
	0x10,                           /* Bit resolution - 16 bits */
	0x01,                           /* Number of samping frequencies - 1 */
	0x80, 0xBB, 0x00,               /* Sampling frequency - 48000 Hz */

	/* Endpoint descriptor for ISO streaming Audio data */
	0x09,                           /* Descriptor size */
	CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
	0x81,                           /* Endpoint address and description */
	0x05,                           /* ISO End point : Async */
	0x60, 0x00,                     /* Transaction size - 96 bytes per frame */
	0x03,                           /* Servicing interval for data transfers */
	0x00,                           /* bRefresh */
	0x00,                           /* bSynchAddress */

	/* Class Specific AS Isochronous Audio Data Endpoint Descriptor */
	0x07,                           /* Descriptor size in bytes */
	0x25,                           /* CS_ENDPOINT descriptor type */
	0x01,                           /* EP_GENERAL sub-descriptor type */
	0x00,                           /* bmAttributes - None  */
	0x00,                           /* bLockDelayUnits - Unused */
	0x00, 0x00                      /* wLockDelay - unused */

#endif
};



const uint8_t CyFxUSBHSConfigDscr3[] __attribute__ ((aligned (32))) =
{
		0x09,	    //bLength
		0x02,	    //bDescriptorType
		0xF9,0x00,	//wTotalLength   (253 Bytes)
		0x04,	    //bNumInterfaces
		0x01,	    // bConfigurationValue
		0x00,	    //iConfiguration
		0x80,	    //bmAttributes   (Bus-powered Device)
		0x32,	    //bMaxPower   (100 mA)

		0x09,	    //bLength
		0x04,	    //bDescriptorType
		0x00,	//bInterfaceNumber
		0x00,	//bAlternateSetting
		0x00,	//bNumEndPoints
		0x01,	//bInterfaceClass   (Audio Device Class)
		0x01,	//bInterfaceSubClass   (Audio Control Interface)
		0x00,	//bInterfaceProtocol
		0x00,	//iInterface

		0x0A,	    //bLength
		0x24,	    //bDescriptorType
		0x01,	    //bDescriptorSubtype
		0x00,0x01,	//bcdADC
		0x64,0x00,  //wTotalLength   (100 Bytes)
		0x02,	    //bInCollection
		0x01,	    //baInterfaceNr(1)
		0x02,	    //baInterfaceNr(2)

		0x0C,       //bLength
		0x24,       //bDescriptorType
		0x02,	    //bDescriptorSubtype
		0x01,	    //bTerminalID
		0x01,0x01,	    //wTerminalType   (USB Streaming)
		0x00,	    //bAssocTerminal
		0x02,	    //bNrChannels   (2 Channels)
		0x03,0x00,  //wChannelConfig
		0x00,	    //iChannelNames
		0x00,	    //iTerminal


		0x0C,		//bLength
		0x24,		//bDescriptorType
		0x02,		//bDescriptorSubtype
		0x02,		//bTerminalID
		0x01,0x02,	//wTerminalType   (Microphone)
		0x00,		//bAssocTerminal
		0x01,		//bNrChannels   (1 Channels)
		0x01,0x00,	//wChannelConfig
		0x00,		//iChannelNames
		0x00,		//iTerminal

		0x09,		//bLength
		0x24,		//bDescriptorType
		0x03,		//bDescriptorSubtype
		0x06,		//bTerminalID
		0x01,0x03,	//wTerminalType(Speaker)
		0x00,		//bAssocTerminal
		0x09,		//bSourceID
		0x00,		//iTerminal

		0x09,		//bLength
		0x24,		//bDescriptorType
		0x03,		//bDescriptorSubtype
		0x07,		//bTerminalID
		0x01,0x01,	//wTerminalType   (USB Streaming)
		0x00,		//bAssocTerminal
		0x08,		//bSourceID
		0x00,		//iTerminal

		0x07,		//bLength
		0x24,		//bDescriptorType
		0x05,		//bDescriptorSubtype
		0x08,		//bUnitID
		0x01,		//bBrInPins
		0x0A,		//baSourceID(1)
		0x00,		//iSelector

		0x0A,		//bLength
		0x24,		//bDescriptorType
		0x06,		//bDescriptorSubtype
		0x09,		//bUnitID
		0x0F,		//bSourceID
		0x01,		//bControlSize
		//bmaControls:
		0x01,		//Channel(0)
		0x02,		//Channel(1)
		0x02,		//Channel(2)
		0x00,		//iFeature

		0x09,		//bLength
		0x24,		//bDescriptorType
		0x06,		//bDescriptorSubtype
		0x0A,		//bUnitID
		0x02,		//bSourceID
		0x01,		//bControlSize
		//bmaControls:
		0x43,		//Channel(0)
		0x00,		//Channel(1)
		0x00,		//iFeature


		0x09,		//bLength
		0x24,		//bDescriptorType
		0x06,		//bDescriptorSubtype
		0x0D,		//bUnitID
		0x02,		//bSourceID
		0x01,		//bControlSize
		//bmaControls:
		0x03,		//Channel(0)
		0x00,		//Channel(1)
		0x00,		//iFeature


		0x0D,		//bLength
		0x24,		//bDescriptorType
		0x04,		//bDescriptorSubtype
		0x0F,		//bUnitID
		0x02,		//bBrInPins
		0x01,		//baSourceID(1)
		0x0D,		//baSourceID(2)
		0x02,		//bNrChannels
		0x03,0x00,		//wChannelConfig
		0x00,		//iChannelNames
		//bmControls:
		0x00,
		0x00,		//iMixer


		0x09,		//bLength
		0x04,		//bDescriptorType
		0x01,		//bInterfaceNumber
		0x00,		//bAlternateSetting
		0x00,		//bNumEndPoints
		0x01,		//bInterfaceClass   (Audio Device Class)
		0x02,		//bInterfaceSubClass   (Audio Streaming Interface)
		0x00,		//bInterfaceProtocol
		0x00,		//iInterface


		0x09,		//bLength
		0x04,		//bDescriptorType
		0x01,		//bInterfaceNumber
		0x01,		//bAlternateSetting
		0x01,		//bNumEndPoints
		0x01,		//bInterfaceClass   (Audio Device Class)
		0x02,		//bInterfaceSubClass   (Audio Streaming Interface)
		0x00,		//bInterfaceProtocol
		0x00,		//iInterface


		0x07,		//bLength
		0x24,		//bDescriptorType
		0x01,		//bDescriptorSubtype
		0x01,		//bTerminalLink
		0x01,		//bDelay
		0x01,0x00,	//wFormatTag   (PCM)


		0x0E,		//bLength
		0x24,		//bDescriptorType
		0x02,		//bDescriptorSubtype
		0x01,		//bFormatType   (FORMAT_TYPE_1)
		0x02,		//bNrChannels   (2 Channels)
		0x02,		//bSubframeSize
		0x10,		//bBitResolution   (16 Bits/sample)
		0x02,		//bSamFreqType   (Discrete sampling frequencies)
		0x80,0xBB,0x00,
		0x44,0xAC,0x00,

		0x09,		//bLength
		0x05,		//bDescriptorType
		0x01,		//bEndpointAddress   (OUT Endpoint)
		0x09,		//bmAttributes	(Transfer: Isochronous / Synch: Adaptive / Usage: Data)
		0xC8,0x00,	//wMaxPacketSize   (200 Bytes)
		0x01,		//bInterval
		0x00,		//bRefresh
		0x00,		//bSynchAddress


		0x07,		//bLength
		0x25,		//bDescriptorType
		0x01,		//bDescriptorSubtype
		0x01,		//bmAttributes   (Sampling Frequency)
		0x01,		//bLockDelayUnits   (Milliseconds)
		0x01,0x00,	//wLockDelay


		0x09,		//bLength
		0x04,		//bDescriptorType
		0x02,		//bInterfaceNumber
		0x00,		//bAlternateSetting
		0x00,		//bNumEndPoints
		0x01,		//bInterfaceClass   (Audio Device Class)
		0x02,		//bInterfaceSubClass   (Audio Streaming Interface)
		0x00,		//bInterfaceProtocol
		0x00,		//iInterface


		0x09,		//bLength
		0x04,		//bDescriptorType
		0x02,		//bInterfaceNumber
		0x01,		//bAlternateSetting
		0x01,		//bNumEndPoints
		0x01,		//bInterfaceClass   (Audio Device Class)
		0x02,		//bInterfaceSubClass   (Audio Streaming Interface)
		0x00,		//bInterfaceProtocol
		0x00,		//iInterface


		0x07,		//bLength
		0x24,		//bDescriptorType
		0x01,		//bDescriptorSubtype
		0x07,		//bTerminalLink
		0x01,		//bDelay
		0x01,0x00,	//wFormatTag   (PCM)


		0x0E,		//bLength
		0x24,		//bDescriptorType
		0x02,		//bDescriptorSubtype
		0x01,		//bFormatType   (FORMAT_TYPE_1)
		0x01,		//bNrChannels   (1 Channels)
		0x02,		//bSubframeSize
		0x10,		//bBitResolution   (16 Bits/sample)
		0x02,		//bSamFreqType   (Discrete sampling frequencies)
		0x80,0xBB,0x00,
		0x44,0xAC,0x00,

		0x09,		//bLength
		0x05,		//bDescriptorType
		0x82,		//bEndpointAddress   (IN Endpoint)
		0x09,		//bmAttributes	(Transfer: Isochronous / Synch: Adaptive / Usage: Data)
		0x64,0x00,	//wMaxPacketSize   (100 Bytes)
		0x01,		//bInterval
		0x00,		//bRefresh
		0x00,		//bSynchAddress


		0x07,		//bLength
		0x25,		//bDescriptorType
		0x01,		//bDescriptorSubtype
		0x01,		//bmAttributes   (Sampling Frequency)
		0x00,		//bLockDelayUnits   (Undefined)
		0x00,0x00,		//wLockDelay


		0x09,		//bLength
		0x04,		//bDescriptorType
		0x03,		//bInterfaceNumber
		0x00,		//bAlternateSetting
		0x01,		//bNumEndPoints
		0x03,		//bInterfaceClass   (Human Interface Device Class)
		0x00,		//bInterfaceSubClass
		0x00,		//bInterfaceProtocol
		0x00,		//iInterface


		0x09,		//bLength
		0x21,		//bDescriptorType
		0x00,0x01,	//bcdHID
		0x00,		//bCountryCode
		0x01,		//bNumDescriptors
		0x22,		//bDescriptorType   (Report descriptor)
		0x3C,0x00,	//bDescriptorLength


		0x07,		//bLength
		0x05,		//bDescriptorType
		0x87,		//bEndpointAddress   (IN Endpoint)
		0x03,		//bmAttributes	(Transfer: Interrupt / Synch: None / Usage: Data)
		0x04,0x00,	//wMaxPacketSize   (4 Bytes)
		0x02		//bInterval
};


#define UVC_ControlInterface_Intfc_0 0
#define UVC_ControlInterface_Intfc_1 1

#define UVC_EndPoint_0 0x82
#define UVC_EndPoint_1 0x83


#define UAC_ControlInterface_Intfc_0 2
#define UAC_ControlInterface_Intfc_1 3
#define UAC_EndPoint_0 0x01
#define UAC_EndPoint_1 0x84

#define UAC_ControlInterface_Intfc_2 4
#define UAC_ControlInterface_Intfc_3 5
#if 1
/*UAC :  Mic*/
#define UMic_BASE_INTRFC_NO 0
#define UMic_1_INTRFC_1 UMic_BASE_INTRFC_NO
#define UMic_1_INTRFC_2 UMic_1_INTRFC_1 + 1
#define UMic_1_INTRFC_3 UMic_1_INTRFC_2 + 1
#define UMic_1_INTRFC_4 UMic_1_INTRFC_3 + 1
#endif
#define ENDPOINT_CX3_SND_CARD_ISO_MIC                 0x82          /* EP 1 IN */
#define ENDPOINT_CX3_SND_CARD_ISO_SPK                 0x01          /* EP 1 OUT */
#define ENDPOINT_CX3_SND_CARD_INT_HID		          0x87

const uint8_t CyFxUSBHSConfigDscrStackOvflw[] __attribute__ ((aligned (32))) =
{
		0x09,               	// Size : 9 Bytes
		0x02,               	// Configuration Descriptor (0x02)
		0xB4,               	// Ved simpel Audio Function
		0x00,               	//      2. Byte af Total Length   // 228
		0x03,               	// Number of Interfaces: 3
		0x01,               	// bConfigurationValue, Value to use as an argument to select this configuration
		0x00,               	// iConfiguration, Index of String Descriptor describing this configuration
		0x80,               	// bmAttributes, 0b01100000 -> D6: Self-powered, D7: Reserved (set to one)
		0xFA,               	// Maximum Power : 250 * 2mA = 0,5A

		//ID    - INTERFACE 0 Control
		0x09,               	// Size : 9 Bytes
		0x04,       			// Interface Descriptor (0x04)
		0x00,      				// Number of Interface:                     Interface nr 0
		0x00,       			// Value used to select alternative setting
		0x00,       			// Number of Endpoints used for this interface, 0
		0x01,      				// Class Code (Assigned by USB Org),        AUDIO
		0x01,       			// Subclass Code (Assigned by USB Org),     AUDIOCONTROL
		0x00,       			// Protocol Code (Assigned by USB Org)
		0x00,       			// Index of String Descriptor Describing this interface

		//ACID  - HEADER
		0x0A,     		    	// Size : 10 Bytes
		0x24,           		// CS_INTERFACE Descriptor Type
		0x01,           		// HEADER descriptor subtype
		0x00,0x01,      		// Audio Device compliant to the USB Audio specification version 1.00
		//0x64,0x00,    		// 100 bytes - Total number of bytes returned for the class-specific AudioControl interface descriptor.
								// Includes the combined length of
		//this descriptor header and all Unit and Terminal descriptors.
		0x34,0x00,      		// wTotalLength
		0x02,           		// bInCollection -> Number of streaming interfaces = 2
		0x01,           		// baInterfaceNr(1) -> 0x01 = 1 -> Interface number of the first AudioStreaming interface in the Collection
		0x02,           		// baInterfaceNr(2) -> 0x02 = 2 -> Interface number of the second AudioStreaming interface in the Collection

		//ACID  - INPUT_TERMINAL    ID = 1
		0x0C,           		// size : 12 bytes
		0x24,           		// CS_INTERFACE Descriptor Type
		0x02,           		// INPUT_TERMINAL - Descriptor subtype = 2
		0x01,           		// ID of this Input Terminal. // Constant uniquely identifying the Terminal within the audio function.
		0x01,0x01,      		// wTerminalType -> 0x0101 = USB streamming
		0x00,           		// bAssocTerminal -> 0x00 = No association.
		//0x03,         		// bAssocTerminal -> 0x03 = Associated with OUTPUT TERMINAL 3
		0x02,           		// bNrChannels -> 0x02 two channel.
		0x03,0x00,      		// wChannelConfig -> 0x0003 = stereo, Right / Left    // se Audio Devices Dok side 34
		//0x00,0x00,      		// wChannelConfig -> 0x0000 = mono ?
		0x00,           		// iChannelNames -> 0x00 = Unused.
		0x00,           		// iTerminal -> 0x00 = Unused.

		//ACID  - INPUT_TERMINAL    ID = 4
		0x0C,           		// size : 12 bytes
		0x24,           		// CS_INTERFACE Descriptor Type
		0x02,           		// INPUT_TERMINAL - Descriptor subtype
		0x04,          			// bTerminalID -> ID of this Input Terminal = 4
		0x01,0x02,      		// wTerminalType -> 0x0201 = Microphone
		0x00,           		// bAssocTerminal -> 0x00 = No association.
		//0x06,         		// bAssocTerminal -> 0x06 = Associated with OUTPUT TERMINAL 6
		0x01,           		// bNrChannels -> 0x01 one channel.
		0x01,0x00,      		// wChannelConfig -> Left Front       <- original fra ex.
		//0x00,0x00,    		// wChannelConfig -> 0x0000 = mono
		0x00,           		// iChannelNames -> 0x00 = Unused.
		0x00,           		// iTerminal -> 0x00 = Unused.

		//ACID  - OUTPUT_TERMINAL   ID = 3
		0x09,           		// size : 9 Bytes
		0x24,           		// CS_INTERFACE Descriptor Type
		0x03,           		// OUTPUT_TERMINAL - Descriptor subtype
		0x03,           		// bTerminalID -> ID of this Output Terminal = 3
		0x01,0x03,      		// wTerminalType -> 0x0301 = Speaker
		0x00,           		// bAssocTerminal -> 0x00 = Unused
		//0x01,         		// bAssocTerminal -> 0x01 = Associated with INPUT TERMINAL 1
		//0x02,         		// bSourceID -> 0x02 = From FEATURE_UNIT ID 2 = USB stream
		0x01,           		// bSourceID -> 0x01 = From Input Terminal ID 1
		0x00,           		// iTerminal -> 0x00 = Unused.


		//ACID  - OUTPUT_TERMINAL   ID = 6
		0x09,           // Size : 9 Bytes
		0x24,           // CS_INTERFACE Descriptor Type
		0x03,           // OUTPUT_TERMINAL - Descriptor subtype
		0x06,           // bTerminalID -> ID of this Output Terminal = 6
		0x01,0x01,      // wTerminalType -> 0x0101 = USB streaming
		0x00,           // bAssocTerminal -> 0x00 = Unused
		//0x04,         // bAssocTerminal -> 0x04 = Associated with INPUT TERMINAL 4
		//0x09,         // bSourceID -> 0x09 = From Selector Unit ID 9
		0x04,           // bSourceID -> 0x04 = From INPUT_TERMINAL ID 4
		0x00,           // iTerminal -> 0x00 = Unused.


		/* #####   INTERFACE 1     -     OUT  ##### */

		//ID    - INTERFACE 1/0 Stream
		0x09,                       // Size : 9 Bytes
		0x04,                       // Interface Descriptor (0x04)
		0x01,                       // bInterfaceNumber -> 0x01 Interface ID = 1        Number of this interface. Zero-based value identifying the index in the array
		//of concurrent interfaces supported by this configuration.
		0x00,                       // bAlternateSetting -> 0x00 = index of this interface's alternate setting
		0x00,                       // bNumEndpoints -> 0x00 = 0 Endpoints to this interface
		0x01,                       // bInterfaceClass -> 0x01 = Audio Interface
		0x02,                       // bInterfaceSubclass -> 0x02 = AUDIO_STREAMING
		0x00,                       // bInterfaceProtocol -> 0x00 = Unused
		0x00,                       // iInterface -> 0x00 = Unused

		//ID    - INTERFACE 1/1 Stream
		0x09,                       // Size : 9 Bytes
		0x04,                       // Interface Descriptor (0x04)
		0x01,                       // bInterfaceNumber -> 0x01 Interface ID = 1
		0x01,                       // bAlternateSetting -> 0x01 = index of this interface's alternate setting
		0x01,                       // bNumEndpoints -> 0x01 = 1 Endpoints to this interface
		0x01,                       // bInterfaceClass -> 0x01 = Audio Interface
		0x02,                       // bInterfaceSubclass -> 0x02 = AUDIO_STREAMING
		0x00,                       // bInterfaceProtocol -> 0x00 = Unused
		0x00,                       // iInterface -> 0x00 = Unused

		//ASID  - GENERAL
		0x07,                   // Size : 7 Bytes
		0x24,                   // CS_INTERFACE Descriptor Type
		0x01,                   // bDescriptorSubtype -> 0x01 = GENERAL subtype
		0x01,                   // bTerminalLink -> 0x01 = The Terminal ID of the Terminal to which the endpoint of this interface is connected.
		0x01,                   // bDelay -> 0x01 = Delay (delta) introduced by the data path (see Section 3.4, ?Inter Channel Synchronization? - in Audio
		//Devices). Expressed in number of frames.
		0x01,0x00,              // wFormatTag -> 0x0001 = PCM

		//ASID  - FORMAT_TYPE
		0x0E,                   // Size : 14 Bytes
		0x24,                   // CS_INTERFACE Descriptor Type
		0x02,                   // bDescriptorSubtype -> 0x02 = FORMAT_TYPE
		0x01,                   // bFormatType -> 0x01 = FORMAT_TYPE_I -> ref: A.1.1  Audio Data Format Type I Codes -> Audio Data Format Dok
		0x02,                   // bNrChannels -> 0x02 = Two channels
		0x02,                   // bSubFrameSize -> 0x02 = 2 bytes pr audio subframe
		0x10,                   // bBitResolution -> 0x10 = 16 bit pr sample
		0x02,                   // bSamFreqType -> 0x02 = 2 sample frequencies supported
		0x80,0xBB,0x00,         // tSamFreq -> 0xBB80 = 48000 Hz
		0x00,0x7D,0x00,         // tSamFreq -> 0x7D00 = 32000 Hz
		//0x44,0xAC,0x00,

		//ED    - ENDPOINT  OUT
		0x09,                   // Size : 9 Bytes
		0x05,                   // 0x05 -> ENDPOINT Descriptor Type
		0x01,                   // bEndpointAddress -> 0x01 = adress 1, OUT, -> ref 9.6.6 Endpoint -> usb_20 Dok
		0x09,                   // bmAttributes -> 0b00001001 -> Bits 0-1 = 01 = Isochronous , Bits 2-3 = 10 = Adaptive
		//AUDIO_MAX_SAMPLES * sizeof ( AUDIO_PLAY_SAMPLE ), 0x00,  // wMaxPacketSize -> 48 * 4 = 0x0030 :Maximum packet size this endpoint is capable of sending or
		//receiving when this configuration is selected.
		0xC8,00,
		0x01,                   // bInterval -> 0x01 = 1 millisecond
		0x00,                   // ?? not described -> 0x00 = Unused
		0x00,                   // ?? not described -> 0x00 = Unused

		//CSED     - CS ENDPOINT
		0x07,               	// Size : 7 Bytes
		0x25,               	// CS_ENDPOINT
		0x01,               	// bDescriptorSubtype -> 0x01 = GENERAL
		0x01,               	// bmAttributes -> 0b00000001 = Bit 1 = 1 => Sample Freq Control is supported by this endpoint
		0x00,               	// bLockDelayUnits -> 0x00 = Indicates the units used for the wLockDelay field: 0 = Undefined
		0x00,0x00,          	//  the time it takes this endpoint to reliably lock its internal clock recovery circuitry.


		/* #####   INTERFACE 2     -     IN  ##### */


		//ID    - INTERFACE 2/0 Stream
		0x09,                   // Size : 9 Bytes
		0x04,                   // Interface Descriptor (0x04)
		0x02,                   // bInterfaceNumber -> 0x02 Interface ID = 2
		0x00,                   // bAlternateSetting -> 0x00 = Value used to select this alternate setting for the interface identified in the prior field
		0x00,                   // bNumEndpoints -> 0x00 = 0 -> Number of endpoints used by this interface
		0x01,                   // bInterfaceClass -> 0x01 = 1 = AUDIO
		0x02,                   // bInterfaceSubClass -> 0x02 = AUDIO_STREAMING
		0x00,                   // bInterfaceProtocol -> 0x00 = Unused
		0x00,                   // iInterface -> 0x00 = Unused -> Index of string descriptor.

		//ID    - INTERFACE 2/1 Stream
		0x09,                   // Size : 9 Bytes
		0x04,                   // Interface Descriptor (0x04)
		0x02,                   // bInterfaceNumber -> 0x02 Interface ID = 2
		0x01,                   // bAlternateSetting -> 0x01 = Value used to select this alternate setting for the interface identified in the prior field
		0x01,                   // bNumEndpoints -> 0x01 = 1 -> Number of endpoints used by this interface
		0x01,                   // bInterfaceClass -> 0x01 = 1 = AUDIO
		0x02,                   // bInterfaceSubClass -> 0x02 = AUDIO_STREAMING
		0x00,                   // bInterfaceProtocol -> 0x00 = Unused
		0x00,                   // iInterface -> 0x00 = Unused -> Index of string descriptor.

		//ASID      -    GENERAL
		0x07,                   // Size : 7 Bytes
		0x24,                   // CS_INTERFACE Descriptor Type
		0x01,                   // GENERAL Descriptor
		0x06,                   // bTerminalLink -> 0x06 = The Terminal ID of the Terminal to which the endpoint of this interface is connected = 6
		0x01,                   // bDelay -> 0x01 = Delay (delta) introduced by the data path (see Section 3.4, ?Inter Channel Synchronization? - in Audio
		//Devices). Expressed in number of frames.
		0x01,0x00,              // wFormatTag -> 0x0001 = PCM

		//ASID       -    FORMAT_TYPE
		0x0E,                   // Size : 14 Bytes
		0x24,                   // CS_INTERFACE Descriptor Type
		0x02,                   // bDescriptorSubtype -> 0x02 = FORMAT_TYPE
		0x01,                   // bFormatType -> 0x01 = FORMAT_TYPE_I -> ref: A.1.1  Audio Data Format Type I Codes -> Audio Data Format Dok
		0x02,                   // bNrChannels -> 0x02 = Two channels
		0x02,                   // bSubFrameSize -> 0x02 = 2 bytes pr audio subframe
		//0x03,                 // bSubFrameSize -> 0x03 = 3 bytes pr audio subframe
		0x10,                   // bBitResolution -> 0x10 = 16 bit pr sample
		//0x18,                 // bBitResolution -> 0x18 = 24 bit pr sample
		0x02,                   // bSamFreqType -> 0x02 = 2 sample frequencies supported
		0x80,0xBB,0x00,         // tSamFreq -> 0xBB80 = 48000 Hz
		0x00,0x7D,0x00,         // tSamFreq -> 0x7D00 = 32000 Hz
		//0x44,0xAC,0x00,       // 44100 Hz


		//ED      -   ENDPOINT  IN
		0x09,                   // Size : 9 Bytes
		0x05,                   // 0x05 -> ENDPOINT Descriptor Type
		0x82,                   // bEndpointAddress -> 0x82 = adress 2, IN, -> ref 9.6.6 Endpoint -> usb_20 Dok
		0x05,                   // bmAttributes -> 0b00000101 -> Bits 0-1 = 01 = Isochronous , Bits 2-3 = 01 = Asynchronous
		//AUDIO_MAX_SAMPLES * (sizeof ( AUDIO_PLAY_SAMPLE )), 0x00,     // wMaxPacketSize -> 48 * 4 = 0x0030 :Maximum packet size this endpoint is capable of sending or
		//receiving when this configuration is selected.
		0xC8,0x00,
		0x01,                   // bInterval -> 0x01 = 1 millisecond
		0x00,                   // bRefresh -> ??
		0x00,                   // bSynchAddress -> ??

		//CSED      - CS ENDPOINT
		0x07,               	// Size : 7 Bytes
		0x25,              		// bDescriptorType -> 0x25 = CS_ENDPOINT
		0x01,               	// bDescriptorSubtype -> 0x01 = GENERAL
		0x01,               	// bmAttributes -> 0b00000001 = Bit 1 = 1 => Sample Freq Control is supported by this endpoint
		0x00,               	// bLockDelayUnits -> 0x00 = Indicates the units used for the wLockDelay field: 0 = Undefined
		0x00,0x00,          	//  the time it takes this endpoint to reliably lock its internal clock recovery circuitry
};

const uint8_t CyFxUSBHSConfigDscr[] __attribute__ ((aligned (32))) =
{
	0x09,               // Size : 9 Bytes
	0x02,               // Configuration Descriptor (0x02)
	0xF8,               // Ved simpel Audio Function
	0x00,               //      2. Byte af Total Length   // 228
	0x03,               // Number of Interfaces: 3
	0x01,               // bConfigurationValue, Value to use as an argument to select this configuration
	0x00,               // iConfiguration, Index of String Descriptor describing this configuration
	0x80,   			// bmAttributes, 0b01100000 -> D6: Self-powered, D7: Reserved (set to one)
	0xFA,

	//ID    - INTERFACE 0 Control
	0x09,       // Size : 9 Bytes
	0x04,       // Interface Descriptor (0x04)
	0x00,       // Number of Interface:                     Interface nr 0
	0x00,       // Value used to select alternative setting
	0x01,       // Number of Endpoints used for this interface, 0
	0x01,       // Class Code (Assigned by USB Org),        AUDIO
	0x01,       // Subclass Code (Assigned by USB Org),     AUDIOCONTROL
	0x00,       // Protocol Code (Assigned by USB Org)
	0x00,       // Index of String Descriptor Describing this interface

	//ACID  - HEADER
    0x0A,           // Size : 10 Bytes
    0x24,           // CS_INTERFACE Descriptor Type
    0x01,           // HEADER descriptor subtype
    0x00,0x01,      // Audio Device compliant to the USB Audio specification version 1.00
    0x41,0x00,      // wTotalLength
    0x02,           // bInCollection -> Number of streaming interfaces = 2
    0x01,           // baInterfaceNr(1) -> 0x01 = 1 -> Interface number of the first AudioStreaming interface in the Collection
    0x02,           // baInterfaceNr(2) -> 0x02 = 2 -> Interface number of the second AudioStreaming interface in the Collection

    //AC Feature Unit Descriptor:
    0x0D,   //bLength
    0x24,   //bDescriptorType
    0x06,   //bDescriptorSubtype
    0x02,   //bUnitID
    0x01,   //bSourceID
    0x02,   //bControlSize
    0x01,   //Channel(0)
    0x00,   //Channel(1)
    0x00,
    0x00,
    0x00,
    0x00,   //Channel(2)
    0x00,   //iFeature

    //ACID  - INPUT_TERMINAL    ID = 1
    0x0C,           // size : 12 bytes
    0x24,           // CS_INTERFACE Descriptor Type
    0x02,           // INPUT_TERMINAL - Descriptor subtype = 2
    0x01,           // ID of this Input Terminal. // Constant uniquely identifying the Terminal within the audio function.
    0x01,0x01,      // wTerminalType -> 0x0101 = USB streamming
    0x00,           // bAssocTerminal -> 0x00 = No association.
    0x02,           // bNrChannels -> 0x02 two channel.
    0x03,0x00,      // wChannelConfig -> 0x0003 = stereo, Right / Left    // se Audio Devices Dok side 34
    0x00,           // iChannelNames -> 0x00 = Unused.
    0x00,           // iTerminal -> 0x00 = Unused.


    //ACID  - OUTPUT_TERMINAL   ID = 3
    0x09,           // size : 9 Bytes
    0x24,           // CS_INTERFACE Descriptor Type
    0x03,           // OUTPUT_TERMINAL - Descriptor subtype
    0x03,           // bTerminalID -> ID of this Output Terminal = 3
    0x01,0x03,      // wTerminalType -> 0x0301 = Speaker
    0x00,           // bAssocTerminal -> 0x00 = Unused
    0x02,           // bSourceID -> 0x01 = From Input Terminal ID 1
    0x00,           // iTerminal -> 0x00 = Unused.


    //ACID  - INPUT_TERMINAL    ID = 4
    0x0C,           // size : 12 bytes
    0x24,           // CS_INTERFACE Descriptor Type
    0x02,           // INPUT_TERMINAL - Descriptor subtype
    0x04,           // bTerminalID -> ID of this Input Terminal = 4
    0x01,0x02,      // wTerminalType -> 0x0201 = Microphone
    0x00,           // bAssocTerminal -> 0x00 = No association.
    0x02,           // bNrChannels -> 0x01 one channel.
    0x03,0x00,      // wChannelConfig -> Left Front       <- original fra ex.
    0x00,           // iChannelNames -> 0x00 = Unused.
    0x00,           // iTerminal -> 0x00 = Unused.


    //ACID  - OUTPUT_TERMINAL   ID = 6
    0x09,           // Size : 9 Bytes
    0x24,           // CS_INTERFACE Descriptor Type
    0x03,           // OUTPUT_TERMINAL - Descriptor subtype
    0x05,           // bTerminalID -> ID of this Output Terminal = 6
    0x01,0x01,      // wTerminalType -> 0x0101 = USB streaming
    0x00,           // bAssocTerminal -> 0x00 = Unused
    0x04,           // bSourceID -> 0x04 = From INPUT_TERMINAL ID 4
    0x00,           // iTerminal -> 0x00 = Unused.

      //ED    - ENDPOINT  OUT
    0x09,                   // Size : 9 Bytes
    0x05,                   // 0x05 -> ENDPOINT Descriptor Type
    0x86,                   // bEndpointAddress -> 0x01 = adress 1, OUT, -> ref 9.6.6 Endpoint -> usb_20 Dok
    0x03,                   // bmAttributes -> 0b00001001 -> Bits 0-1 = 01 = Isochronous , Bits 2-3 = 10 = Adaptive
    0x02, 0x00,             // wMaxPacketSize -> 48 * 4 = 0x0030 :Maximum packet size this endpoint is capable of sending or receiving when this configuration is selected.
    0x30,                   // bInterval -> 0x01 = 1 millisecond
    0x00,                   // ?? not described -> 0x00 = Unused
    0x00,                   // ?? not described -> 0x00 = Unused


    /* #####   INTERFACE 1     -     OUT  ##### */
    //ID    - INTERFACE 1/0 Stream
    0x09,                       // Size : 9 Bytes
    0x04,                       // Interface Descriptor (0x04)
    0x01,                       // bInterfaceNumber -> 0x01 Interface ID = 1        Number of this interface. Zero-based value identifying the index in the array of concurrent interfaces supported by this configuration.
    0x00,                       // bAlternateSetting -> 0x00 = index of this interface's alternate setting
    0x00,                       // bNumEndpoints -> 0x00 = 0 Endpoints to this interface
    0x01,                       // bInterfaceClass -> 0x01 = Audio Interface
    0x02,                       // bInterfaceSubclass -> 0x02 = AUDIO_STREAMING
    0x00,                       // bInterfaceProtocol -> 0x00 = Unused
    0x00,                       // iInterface -> 0x00 = Unused

    //ID    - INTERFACE 1/1 Stream
    0x09,                       // Size : 9 Bytes
    0x04,                       // Interface Descriptor (0x04)
    0x01,                       // bInterfaceNumber -> 0x01 Interface ID = 1
    0x01,                       // bAlternateSetting -> 0x01 = index of this interface's alternate setting
    0x01,                       // bNumEndpoints -> 0x01 = 1 Endpoints to this interface
    0x01,                       // bInterfaceClass -> 0x01 = Audio Interface
    0x02,                       // bInterfaceSubclass -> 0x02 = AUDIO_STREAMING
    0x00,                       // bInterfaceProtocol -> 0x00 = Unused
    0x00,                       // iInterface -> 0x00 = Unused

    //ASID  - GENERAL
    0x07,                   // Size : 7 Bytes
    0x24,                   // CS_INTERFACE Descriptor Type
    0x01,                   // bDescriptorSubtype -> 0x01 = GENERAL subtype
    0x01,                   // bTerminalLink -> 0x01 = The Terminal ID of the Terminal to which the endpoint of this interface is connected.
    0x01,                   // bDelay -> 0x01 = Delay (delta) introduced by the data path (see Section 3.4, ?Inter Channel Synchronization? - in Audio Devices). Expressed in number of frames.
    0x01,0x00,              // wFormatTag -> 0x0001 = PCM

    //ASID  - FORMAT_TYPE
    0x0E,                   // Size : 14 Bytes
    0x24,                   // CS_INTERFACE Descriptor Type
    0x02,                   // bDescriptorSubtype -> 0x02 = FORMAT_TYPE
    0x01,                   // bFormatType -> 0x01 = FORMAT_TYPE_I -> ref: A.1.1  Audio Data Format Type I Codes -> Audio Data Format Dok
    0x02,                   // bNrChannels -> 0x02 = Two channels
    0x02,                   // bSubFrameSize -> 0x02 = 2 bytes pr audio subframe
    0x10,                   // bBitResolution -> 0x10 = 16 bit pr sample
    0x02,                   // bSamFreqType -> 0x02 = 2 sample frequencies supported
    0x80,0xBB,0x00,         // tSamFreq -> 0xBB80 = 48000 Hz
    0x00,0x7D,0x00,         // tSamFreq -> 0x7D00 = 32000 Hz

    0x09,
    0x05,
    0x01,
    0x01,
    0xC0,
    0x00,
    0x01,
    0x00,
    0x00, 

    //CSED     - CS ENDPOINT
    0x07,               // Size : 7 Bytes
    0x25,               // CS_ENDPOINT
    0x01,               // bDescriptorSubtype -> 0x01 = GENERAL
    0x01,               // bmAttributes -> 0b00000001 = Bit 1 = 1 => Sample Freq Control is supported by this endpoint
    0x01,               // bLockDelayUnits -> 0x00 = Indicates the units used for the wLockDelay field: 0 = Undefined
    0x01,0x00,          //  the time it takes this endpoint to reliably lock its internal clock recovery circuitry.


    /* #####   INTERFACE 2     -     IN  ##### */
    //ID    - INTERFACE 2/0 Stream
    0x09,                       // Size : 9 Bytes
    0x04,                       // Interface Descriptor (0x04)
    0x01,                       // bInterfaceNumber -> 0x02 Interface ID = 2
    0x02,                       // bAlternateSetting -> 0x00 = Value used to select this alternate setting for the interface identified in the prior field
    0x01,                       // bNumEndpoints -> 0x00 = 0 -> Number of endpoints used by this interface
    0x01,                       // bInterfaceClass -> 0x01 = 1 = AUDIO
    0x02,                       // bInterfaceSubClass -> 0x02 = AUDIO_STREAMING
    0x00,                       // bInterfaceProtocol -> 0x00 = Unused
    0x00,                       // iInterface -> 0x00 = Unused -> Index of string descriptor.

   //ASID      -    GENERAL
    0x07,                   // Size : 7 Bytes
    0x24,                   // CS_INTERFACE Descriptor Type
    0x01,                   // GENERAL Descriptor
    0x01,                   // bTerminalLink -> 0x06 = The Terminal ID of the Terminal to which the endpoint of this interface is connected = 6
    0x01,                   // bDelay -> 0x01 = Delay (delta) introduced by the data path (see Section 3.4, ?Inter Channel Synchronization? - in Audio Devices). Expressed in number of frames.
    0x01,0x00,              // wFormatTag -> 0x0001 = PCM

 //ASID       -    FORMAT_TYPE
    0x0E,                   // Size : 14 Bytes
    0x24,                   // CS_INTERFACE Descriptor Type
    0x02,                   // bDescriptorSubtype -> 0x02 = FORMAT_TYPE
    0x01,                   // bFormatType -> 0x01 = FORMAT_TYPE_I -> ref: A.1.1  Audio Data Format Type I Codes -> Audio Data Format Dok
    0x02,                   // bNrChannels -> 0x02 = Two channels
    0x03,                   // bSubFrameSize -> 0x02 = 2 bytes pr audio subframe
    0x10,                   // bBitResolution -> 0x10 = 16 bit pr sample
    0x02,                   // bSamFreqType -> 0x02 = 2 sample frequencies supported
    0x80,0xBB,0x00,         // tSamFreq -> 0xBB80 = 48000 Hz
    0x00,0x7D,0x00,         // tSamFreq -> 0x7D00 = 32000 Hz


 //ED      -   ENDPOINT  IN
    0x09,                   // Size : 9 Bytes
    0x05,                   // 0x05 -> ENDPOINT Descriptor Type
    0x01,                   // bEndpointAddress -> 0x82 = adress 2, IN, -> ref 9.6.6 Endpoint -> usb_20 Dok
    0x0D,                   // bmAttributes -> 0b00000101 -> Bits 0-1 = 01 = Isochronous , Bits 2-3 = 01 = Asynchronous
    0x20, 0x01,             // wMaxPacketSize -> 48 * 4 = 0x0030 :Maximum packet size this endpoint is capable of sending or receiving when this configuration is selected.
    0x01,                   // bInterval -> 0x01 = 1 millisecond
    0x00,                   // bRefresh -> ??
    0x00,                   // bSynchAddress -> ??


 //ED      -   ENDPOINT  IN
    0x07,                   // Size : 9 Bytes
    0x25,                   // 0x05 -> ENDPOINT Descriptor Type
    0x01,                   // bEndpointAddress -> 0x82 = adress 2, IN, -> ref 9.6.6 Endpoint -> usb_20 Dok
    0x01,                // bmAttributes -> 0b00000101 -> Bits 0-1 = 01 = Isochronous , Bits 2-3 = 01 = Asynchronous
    0x01,
    0x01,0x00,             // wMaxPacketSize -> 48 * 4 = 0x0030 :Maximum packet size this endpoint is capable of sending


    //ID    - INTERFACE 2/1 Stream
    0x09,                       // Size : 9 Bytes
    0x04,                       // Interface Descriptor (0x04)
    0x02,                       // bInterfaceNumber -> 0x02 Interface ID = 2
    0x00,                       // bAlternateSetting -> 0x01 = Value used to select this alternate setting for the interface identified in the prior field
    0x00,                       // bNumEndpoints -> 0x01 = 1 -> Number of endpoints used by this interface
    0x01,                       // bInterfaceClass -> 0x01 = 1 = AUDIO
    0x02,                       // bInterfaceSubClass -> 0x02 = AUDIO_STREAMING
    0x00,                       // bInterfaceProtocol -> 0x00 = Unused
    0x00,                       // iInterface -> 0x00 = Unused -> Index of string descriptor.

    //ID    - INTERFACE 2/1 Stream
    0x09,                       // Size : 9 Bytes
    0x04,                       // Interface Descriptor (0x04)
    0x02,                       // bInterfaceNumber -> 0x02 Interface ID = 2
    0x01,                       // bAlternateSetting -> 0x01 = Value used to select this alternate setting for the interface identified in the prior field
    0x01,                       // bNumEndpoints -> 0x01 = 1 -> Number of endpoints used by this interface
    0x01,                       // bInterfaceClass -> 0x01 = 1 = AUDIO
    0x02,                       // bInterfaceSubClass -> 0x02 = AUDIO_STREAMING
    0x00,                       // bInterfaceProtocol -> 0x00 = Unused
    0x00,                       // iInterface -> 0x00 = Unused -> Index of string descriptor.


    //CSED      - CS ENDPOINT
    0x07,               // Size : 7 Bytes
    0x24,               // bDescriptorType -> 0x25 = CS_ENDPOINT
    0x01,               // bDescriptorSubtype -> 0x01 = GENERAL
    0x05,               // bmAttributes -> 0b00000001 = Bit 1 = 1 => Sample Freq Control is supported by this endpoint
    0x01,               // bLockDelayUnits -> 0x00 = Indicates the units used for the wLockDelay field: 0 = Undefined
    0x01,0x00,          //  the time it takes this endpoint to reliably lock its internal clock recovery circuitry


    //CSED      - CS ENDPOINT
    0x0E,               // Size : 7 Bytes
    0x24,               // bDescriptorType -> 0x25 = CS_ENDPOINT
    0x02,               // bDescriptorSubtype -> 0x01 = GENERAL
    0x01,               // bmAttributes -> 0b00000001 = Bit 1 = 1 => Sample Freq Control is supported by this endpoint
    0x02,0x00,               // bLockDelayUnits -> 0x00 = Indicates the units used for the wLockDelay field: 0 = Undefined
    0x10,
    0x02,          //  the time it takes this endpoint to reliably lock its internal clock recovery circuitry
    0x80,0xBB,0x00,         // tSamFreq -> 0xBB80 = 48000 Hz
    0x00,0x7D,0x00,         // tSamFreq -> 0x7D00 = 32000 Hz

    0x09,
    0x05,
    0x82,
    0x0D,
    0x00,0x02,
    0x01,
    0x00,
    0x00,
 
    0x07,
    0x25,
    0x01,
    0x01,
    0x01,
    0x01,0x00,
    
/*
    0x09,
    0x04,
    0x03,
    0x00,
    0x01,
    0x03,
    0x00,
    0x00,
    0x00,


    0x09,
    0x21,
    0x11,0x01,
    0x00,
    0x01,
    0x22,
    0x17,0x00,
 
    //CSED      - CS ENDPOINT
    0x07,               // Size : 7 Bytes
    0x05,               // bDescriptorType -> 0x25 = CS_ENDPOINT
    0x84,               // bDescriptorSubtype -> 0x01 = GENERAL
    0x03,               // bmAttributes -> 0b00000001 = Bit 1 = 1 => Sample Freq Control is supported by this endpoint
    0x01,0x00,               // bLockDelayUnits -> 0x00 = Indicates the units used for the wLockDelay field: 0 = Undefined
    0x28          		//the time it takes this endpoint to reliably lock its internal clock recovery circuitry
 */
};

const uint8_t CyFxUSBHSConfigDscrKolaveri[] __attribute__ ((aligned (32))) =
{
	0x09,                           /* Descriptor size */
	CY_U3P_USB_CONFIG_DESCR,        /* Configuration descriptor type */
	0xFD,0x00,                      /* Length of this descriptor and all sub descriptors */
	0x04,                           /* Number of interfaces */
	0x01,                           /* Configuration number */
	0x00,                           /* COnfiguration string index */
	0x80,                           /* Config characteristics - bus powered */
	0x64,                           /* Max power consumption of device (in 2mA unit) : 400mA */

#if 1
#if 1
    /*****UAC*******/
    /*Interface Association Descriptor*/
//    0x08,                     //    bLength
//    ES_UVC_INTRFC_ASSN_DESCR, //    bDescriptorType
//    UMic_1_INTRFC_1,                  //    bFirstInterface
//    0x04,                                     //    bInterfaceCount
//    0x01,                                     //    bFunctionClass
//    0x01,                                     //    bFunctionSubClass
//    0x00,                                     //    bFunctionProtocol
//    0x00,                                     //    iFunction

    /*Interface Descriptor:*/
    0x09,                                      //   bLength
    0x04,                                      //   bDescriptorType
    UMic_1_INTRFC_1,                   		   //   bInterfaceNumber
    0x00,                                      //   bAlternateSetting
    0x00,                                      //   bNumEndPoints
    0x01,                                      //   bInterfaceClass   (Audio Device Class)
    0x01,                                      //   bInterfaceSubClass   (Audio Control Interface)
    0x00,                                      //   bInterfaceProtocol
    0x00,                                      //   iInterface

    /*AC Interface Header Descriptor*/
    0x0A,                                      //   bLength
    0x24,                                      //   bDescriptorType
    0x01,                                      //   bDescriptorSubtype
    0x00,0x01,                                 //   bcdADC
    0x64,0x00,                                 //   wTotalLength   (100 Bytes)
    0x02,                                      //   bInCollection
    UMic_1_INTRFC_2,                           //   baInterfaceNr(1)
    UMic_1_INTRFC_3,                           //   baInterfaceNr(2)

    /*AC Input Terminal Descriptor:*/
    /*------------------------------*/
    0x0C,                                      //   bLength
    0x24,                                      //   bDescriptorType
    0x02,                                      //   bDescriptorSubtype
    0x01,                                      //   bTerminalID
    0x01,0x01,                     			   //wTerminalType   (USB Streaming)
    0x00,                      				   //bAssocTerminal
    0x02,                      				   //bNrChannels   (2 Channels)
    0x03,00,                    			   //wChannelConfig
    0x00,                      				   //iChannelNames
    0x00,                                      //iTerminal

    //AC Input Terminal Descriptor:
    0x0C,   //bLength
    0x24,   //bDescriptorType
    0x02,   //bDescriptorSubtype
    0x02,   //bTerminalID
    0x01,0x02,      //wTerminalType   (Microphone)
    0x00,   //bAssocTerminal
    0x01,   //bNrChannels   (2 Channels)
    0x01,0x00,      //wChannelConfig
    0x00,   //iChannelNames
    0x00,   //iTerminal

    //AC Output Terminal Descriptor:
    0x09,   //bLength
    0x24,   //bDescriptorType
    0x03,   //bDescriptorSubtype
    0x06,   //bTerminalID
    0x01,0x03,      //wTerminalType   (Speaker)
    0x00,   //bAssocTerminal
    0x09,   //bSourceID
    0x00,   //iTerminal

    //AC Output Terminal Descriptor:
    0x09,   //bLength
    0x24,   //bDescriptorType
    0x03,   //bDescriptorSubtype
    0x07,   //bTerminalID
    0x01,0x01,      //wTerminalType   (USB Streaming)
    0x00,   //bAssocTerminal
    0x08,   //bSourceID
    0x00,   //iTerminal

    //AC Selector Unit Descriptor:
    0x07,   //bLength
    0x24,   //bDescriptorType
    0x05,   //bDescriptorSubtype
    0x08,   //bUnitID
    0x01,   //bBrInPins
    0x0A,   //baSourceID(1)
    0x00,   //iSelector

    //AC Feature Unit Descriptor:
    0x0A,   //bLength
    0x24,   //bDescriptorType
    0x06,   //bDescriptorSubtype
    0x09,   //bUnitID
    0x0F,   //bSourceID
    0x01,   //bControlSize
    0x01,   //Channel(0)
    0x02,   //Channel(1)
    0x02,   //Channel(2)
    0x00,   //iFeature


    //AC Feature Unit Descriptor:
    0x09,   //bLength
    0x24,   //bDescriptorType
    0x06,   //bDescriptorSubtype
    0x0A,   //bUnitID
    0x02,   //bSourceID
    0x01,   //bControlSize
    0x43,   //Channel(0)
    0x00,   //Channel(1)
    0x00,   //iFeature

    //AC Feature Unit Descriptor:
    0x09,   //bLength
    0x24,   //bDescriptorType
    0x06,   //bDescriptorSubtype
    0x0D,   //bUnitID
    0x02,   //bSourceID
    0x01,   //bControlSize
    0x03,   //Channel(0)
    0x00,   //Channel(1)
    0x00,   //iFeature


    //AC Mixer Unit Descriptor:
    0x0D,   //bLength
    0x24,   //bDescriptorType
    0x04,   //bDescriptorSubtype
    0x0F,   ///bUnitID
    0x02,   //bBrInPins
    0x01,   //baSourceID(1)
    0x0D,   //baSourceID(2)
    0x02,   //bNrChannels
    0x03,0x00,      //wChannelConfig
    0x00,   //iChannelNames
    0x00,
    0x00,   //iMixer

    //Interface Descriptor:
    0x09,   //bLength
    0x04,   //bDescriptorType
    UMic_1_INTRFC_2,        //bInterfaceNumber
    0x00,   //bAlternateSetting
    0x00,   //bNumEndPoints
    0x01,   //bInterfaceClass   (Audio Device Class)
    0x02,   //bInterfaceSubClass   (Audio Streaming Interface)
    0x00,   //bInterfaceProtocol
    0x00,   //iInterface

    //Interface Descriptor:
    0x09,   //bLength
    0x04,   //bDescriptorType
    UMic_1_INTRFC_2,        //bInterfaceNumber
    0x01,   //bAlternateSetting
    0x01,   //bNumEndPoints
    0x01,   //bInterfaceClass   (Audio Device Class)
    0x02,   //bInterfaceSubClass   (Audio Streaming Interface)
    0x00,   //bInterfaceProtocol
    0x00,   //iInterface

    //AS Interface Descriptor:
    0x07,   //bLength
    0x24,   //bDescriptorType
    0x01,   //bDescriptorSubtype
    0x01,   //bTerminalLink
    0x01,   //bDelay
    0x01,0x00,      //wFormatTag   (PCM)

    //AS Format Type 1 Descriptor:
    0x0E,   //bLength
    0x24,   //bDescriptorType
    0x02,   //bDescriptorSubtype
    0x01,   //bFormatType   (FORMAT_TYPE_1)
    0x02,   //bNrChannels   (2 Channels)
    0x02,   //bSubframeSize
    0x10,   //bBitResolution   (16 Bits/sample)
    0x02,    //bSamFreqType   (Discrete sampling frequencies)
    0x80, 0xBB, 0x00,       //tSamFreq(1)   (48000 Hz)
    0x44, 0xAC, 0x00,       //tSamFreq(2)   (44100 Hz)

    //Endpoint Descriptor (Audio/MIDI):
    0x09,   //bLength
    0x05,   //bDescriptorType
    ENDPOINT_CX3_SND_CARD_ISO_SPK,  //bEndpointAddress   (OUT Endpoint)
    0x09,   //bmAttributes  (Transfer: Isochronous / Synch: Adaptive / Usage: Data)
    0xC8,0x00,      //wMaxPacketSize   (200 Bytes)
    0x01,   //bInterval
    0x00,   //bRefresh
    0x00,   //bSynchAddress

    //AS Isochronous Data Endpoint Descriptor:
    0x07,   //bLength
    0x25,   //bDescriptorType
    0x01,   //bDescriptorSubtype
    0x01,   //bmAttributes   (Sampling Frequency)
    0x01,   //bLockDelayUnits   (Milliseconds)
    0x01,0x00,      //wLockDelay

    //Interface Descriptor:
    0x09,   //bLength
    0x04,   //bDescriptorType
    UMic_1_INTRFC_3,        //bInterfaceNumber
    0x00,   //bAlternateSetting
    0x00,   //bNumEndPoints
    0x01,   //bInterfaceClass   (Audio Device Class)
    0x02,   //bInterfaceSubClass   (Audio Streaming Interface)
    0x00,   //bInterfaceProtocol
    0x00,   //iInterface

    //Interface Descriptor:
    0x09,   //bLength
    0x04,   //bDescriptorType
    UMic_1_INTRFC_3,        //bInterfaceNumber
    0x01,   //bAlternateSetting
    0x01,   //bNumEndPoints
    0x01,   //bInterfaceClass   (Audio Device Class)
    0x02,   //bInterfaceSubClass   (Audio Streaming Interface)
    0x00,   //bInterfaceProtocol
    0x00,   //iInterface

    //AS Interface Descriptor:
    0x07,   //bLength
    0x24,   //bDescriptorType
    0x01,   //bDescriptorSubtype
    0x07,   //bTerminalLink
    0x01,   //bDelay
    0x01,0x00,      //wFormatTag   (PCM)

    //AS Format Type 1 Descriptor:
    0x0E,   //bLength
    0x24,   //bDescriptorType
    0x02,   //bDescriptorSubtype
    0x01,   //bFormatType   (FORMAT_TYPE_1)
    0x01,   //bNrChannels   (2 Channels)
    0x02,   //bSubframeSize
    0x10,   //bBitResolution   (16 Bits/sample)
    0x02,   //bSamFreqType   (Discrete sampling frequencies)
    0x80, 0xBB, 0x00,       //tSamFreq(1)   (16000 Hz)
    0x44, 0xAC, 0x00,       //tSamFreq(2)   (44100 Hz)

    //Endpoint Descriptor (Audio/MIDI):
    0x09,   //bLength
    0x05,   //bDescriptorType
    ENDPOINT_CX3_SND_CARD_ISO_MIC,  //bEndpointAddress   (IN Endpoint)
    0x09,   //bmAttributes  (Transfer: Isochronous / Synch: Adaptive / Usage: Data)
    0x64, 0x00,     //wMaxPacketSize   (96 Bytes)
    0x01,   //bInterval
    0x00,   //bRefresh
    0x00,   //bSynchAddress

    //AS Isochronous Data Endpoint Descriptor:
    0x07,   //bLength
    0x25,   //bDescriptorType
    0x01,   //bDescriptorSubtype
    0x01,   //bmAttributes   (Sampling Frequency)
    0x00,   //bLockDelayUnits   (Undefined)
    0x00,0x00,      //wLockDelay

   // Interface Descriptor:
    //------------------------------
    0x09,	//bLength
    0x04,	//bDescriptorType
    UMic_1_INTRFC_4,	//bInterfaceNumber
    0x00,	//bAlternateSetting
    0x01,	//bNumEndPoints
    0x03,	//bInterfaceClass   (Human Interface Device Class)
    0x00,	//bInterfaceSubClass
    0x00,	//bInterfaceProtocol
    0x00,	//iInterface

    //HID Descriptor:
    //------------------------------
    0x09,	//bLength
    0x21,	//bDescriptorType
    0x00,0x01,	//bcdHID
    0x00,	//bCountryCode
    0x01,	//bNumDescriptors
    0x22,	//bDescriptorType   (Report descriptor)
    0x3C,0x00,	//bDescriptorLength

   // Endpoint Descriptor:
   // ------------------------------
    0x07,	//bLength
    0x05,	//bDescriptorType
    ENDPOINT_CX3_SND_CARD_INT_HID,	//bEndpointAddress   (IN Endpoint)
    0x03,	//bmAttributes	(Transfer: Interrupt / Synch: None / Usage: Data)
    0x04,0x00,	//wMaxPacketSize   (4 Bytes)
    0x02,	//bInterval

#endif
#endif
};

/* Standard High Speed Configuration Descriptor */
const uint8_t CyFxUSBHSConfigDscrT[] __attribute__ ((aligned (32))) =
{
		/* Configuration descriptor */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_CONFIG_DESCR,        /* Configuration descriptor type */
		0x8C,0x01,                      /* Length of this descriptor and all sub descriptors */
		0x06,                           /* Number of interfaces */
		0x01,                           /* Configuration number */
		0x00,                           /* COnfiguration string index */
		0x80,                           /* Config characteristics - bus powered */
		0xFA,                           /* Max power consumption of device (in 2mA unit) : 400mA */


#if 1
		/*Total size 0xBD*/
		/* Interface association descriptor */
		0x08,                           /* Descriptor size */
		CY_FX_INTF_ASSN_DSCR_TYPE,      /* Interface association descr type */
		UVC_ControlInterface_Intfc_0,   /* I/f number of first video control i/f */
		0x02,                           /* Number of video streaming i/f */
		0x0E,                           /* CC_VIDEO : Video i/f class code */
		0x03,                           /* SC_VIDEO_INTERFACE_COLLECTION : subclass code */
		0x00,                           /* Protocol : not used */
		0x00,                           /* String desc index for interface */

		/* Standard video control interface descriptor */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		UVC_ControlInterface_Intfc_0,   /* Interface number */
		0x00,                           /* Alternate setting number */
		0x01,                           /* Number of end points */
		0x0E,                           /* CC_VIDEO : Interface class */
		0x01,                           /* CC_VIDEOCONTROL : Interface sub class */
		0x00,                           /* Interface protocol code */
		0x00,                           /* Interface descriptor string index */

		/* Class specific VC interface header descriptor */
		0x0D,                           /* Descriptor size */
		0x24,                           /* Class Specific I/f header descriptor type */
		0x01,                           /* Descriptor sub type : VC_HEADER */
		0x00,0x01,                      /* Revision of class spec : 1.0 */
		0x50,0x00,                      /* Total size of class specific descriptors (till output terminal) */
		0x00,0x6C,0xDC,0x02,            /* Clock frequency : 48MHz */
		0x01,                           /* Number of streaming interfaces */
		0x01,                           /* Video streaming I/f 1 belongs to VC i/f */

		/* Input (camera) terminal descriptor */
		0x12,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x02,                           /* Input Terminal Descriptor type */
		0x01,                           /* ID of this terminal */
		0x01,0x02,                      /* Camera terminal type */
		0x00,                           /* No association terminal */
		0x00,                           /* String desc index : not used */
		0x00,0x00,                      /* No optical zoom supported */
		0x00,0x00,                      /* No optical zoom supported */
		0x00,0x00,                      /* No optical zoom supported */
		0x03,                           /* Size of controls field for this terminal : 3 bytes */
		0x00,0x00,0x00,                 /* No controls supported */

		/* Processing unit descriptor */
		0x0C,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x05,                           /* Processing unit descriptor type */
		0x02,                           /* ID of this terminal */
		0x01,                           /* Source ID : 1 : conencted to input terminal */
		0x00,0x40,                      /* Digital multiplier */
		0x03,                           /* Size of controls field for this terminal : 3 bytes */
		0x00,0x00,0x00,                 /* No controls supported */
		0x00,                           /* String desc index : not used */

		/* Extension unit descriptor */
		0x1C,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x06,                           /* Extension unit descriptor type */
		0x03,                           /* ID of this terminal */
		0xFF,0xFF,0xFF,0xFF,            /* 16 byte GUID */
		0xFF,0xFF,0xFF,0xFF,
		0xFF,0xFF,0xFF,0xFF,
		0xFF,0xFF,0xFF,0xFF,
		0x00,                           /* Number of controls in this terminal */
		0x01,                           /* Number of input pins in this terminal */
		0x02,                           /* Source ID : 2 : connected to proc unit */
		0x03,                           /* Size of controls field for this terminal : 3 bytes */
		0x00,0x00,0x00,                 /* No controls supported */
		0x00,                           /* String desc index : not used */

		/* Output terminal descriptor */
		0x09,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x03,                           /* Output terminal descriptor type */
		0x04,                           /* ID of this terminal */
		0x01,0x01,                      /* USB Streaming terminal type */
		0x00,                           /* No association terminal */
		0x03,                           /* Source ID : 3 : connected to extn unit */
		0x00,                           /* String desc index : not used */

		/* Video control status interrupt endpoint descriptor */
		0x07,                           /* Descriptor size */
		CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
		UVC_EndPoint_0,                 /* Endpoint address and description */
		CY_U3P_USB_EP_INTR,             /* Interrupt end point type */
		0x40,0x00,                      /* Max packet size = 64 bytes */
		0x08,                           /* Servicing interval : 8ms */

		/* Class specific interrupt endpoint descriptor */
		0x05,                           /* Descriptor size */
		0x25,                           /* Class specific endpoint descriptor type */
		CY_U3P_USB_EP_INTR,             /* End point sub type */
		0x40,0x00,                      /* Max packet size = 64 bytes */

		/* Standard video streaming interface descriptor (alternate setting 0) */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		UVC_ControlInterface_Intfc_1,   /* Interface number */
		0x00,                           /* Alternate setting number */
		0x00,                           /* Number of end points : zero bandwidth */
		0x0E,                           /* Interface class : CC_VIDEO */
		0x02,                           /* Interface sub class : CC_VIDEOSTREAMING */
		0x00,                           /* Interface protocol code : undefined */
		0x00,                           /* Interface descriptor string index */

		/* Class-specific video streaming input header descriptor */
		0x0E,                           /* Descriptor size */
		0x24,                           /* Class-specific VS i/f type */
		0x01,                           /* Descriptotor subtype : input header */
		0x01,                           /* 1 format desciptor follows */
		0x19,0x00,                      /* Total size of class specific VS descr */
		CY_FX_EP_ISO_VIDEO,             /* EP address for ISO video data */
		0x00,                           /* No dynamic format change supported */
		0x04,                           /* Output terminal ID : 4 */
		0x01,                           /* Still image capture method 1 supported */
		0x01,                           /* Hardware trigger supported for still image */
		0x00,                           /* Hardware to initiate still image capture */
		0x01,                           /* Size of controls field : 1 byte */
		0x00,                           /* D2 : Compression quality supported */

		/* Class specific VS format descriptor */
		0x0B,                           /* Descriptor size */
		0x24,                           /* Class-specific VS i/f type */
		0x06,                           /* Descriptotor subtype : VS_FORMAT_MJPEG */
		0x01,                           /* Format desciptor index */
		0x01,                           /* 1 Frame desciptor follows */
		0x01,                           /* Uses fixed size samples */
		0x01,                           /* Default frame index is 1 */
		0x00,                           /* Non interlaced stream not reqd. */
		0x00,                           /* Non interlaced stream not reqd. */
		0x00,                           /* Non interlaced stream */
		0x00,                           /* CopyProtect: duplication unrestricted */

		/* Class specific VS frame descriptor */
		0x1E,                           /* Descriptor size */
		0x24,                           /* Class-specific VS I/f Type */
		0x07,                           /* Descriptotor subtype : VS_FRAME_MJPEG */
		0x01,                           /* Frame desciptor index */
		0x00,                           /* Still image capture method not supported */
		0xB0,0x00,                      /* Width of the frame : 176 */
		0x90,0x00,                      /* Height of the frame : 144 */
		0x00,0xC0,0x5D,0x00,            /* Min bit rate bits/s */
		0x00,0xC0,0x5D,0x00,            /* Min bit rate bits/s */
		0x00,0x58,0x02,0x00,            /* Maximum video or still frame size in bytes */
		0x2A,0x2C,0x0A,0x00,            /* Default frame interval */
		0x01,                           /* Frame interval type : No of discrete intervals */
		0x2A,0x2C,0x0A,0x00,            /* Frame interval 3 */

		/* Standard video streaming interface descriptor (Alternate Setting 1) */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		UVC_ControlInterface_Intfc_1,   /* Interface number */
		0x01,                           /* Alternate setting number */
		0x01,                           /* Number of end points : 1 ISO EP */
		0x0E,                           /* Interface class : CC_VIDEO */
		0x02,                           /* Interface sub class : CC_VIDEOSTREAMING */
		0x00,                           /* Interface protocol code : Undefined */
		0x00,                           /* Interface descriptor string index */

		/* Endpoint descriptor for ISO streaming video data */
		0x07,                           /* Descriptor size */
		CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
		UVC_EndPoint_1,                 /* Endpoint address and description */
		0x05,                           /* ISO End point : Async */
		CY_FX_EP_ISO_VIDEO_PKT_SIZE_L,  /* 1 transaction per microframe */
		CY_FX_EP_ISO_VIDEO_PKT_SIZE_H,  /* CY_FX_EP_ISO_VIDEO_PKT_SIZE max bytes */
		0x01 ,                           /* Servicing interval for data transfers */

#endif

#if 1
		/*UAC Total Size= 0x63*/
		/*Interface Association Descriptor*/
		0x08,                               /* bLength */
		ES_UVC_INTRFC_ASSN_DESCR,           /* bDescriptorType */
		UAC_ControlInterface_Intfc_0,       /* bFirstInterface */
		0x02,                               /* bInterfaceCount */
		0x01,                               /* bFunctionClass */
		0x01,                               /* bFunctionSubClass */
		0x00,                               /* bFunctionProtocol */
		0x00,                               /* iFunction */

		/* Standard Audio Control Interface Descriptor */
		0x09,                           /* Descriptor Size */
		CY_U3P_USB_INTRFC_DESCR,		/* Interface Descriptor Type */
		UAC_ControlInterface_Intfc_0,   /* Interface number */
		0x00,                           /* Alternate setting */
		0x00,                           /* Number of endpoints - 0 endpoints */
		0x01,                           /* Interface Class - Audio */
		0x01,                           /* Interface SubClass - Audio Control */
		0x00,                           /* Interface Protocol - Unused */
		0x00,                           /* Interface string index */

		/* Class Specific Audio Control Interface Descriptor */
		0x09,                           /* Descriptor Size */
		0x24,                           /* Descriptor Type - CS_INTERFACE */
		0x01,                           /* Descriptor SubType - Header */
		0x00, 0x01,                     /* Revision of class specification - 1.0 */
		0x1E, 0x00,                     /* Total size of class specific descriptors */
		0x01,                           /* Number of streaming Interfaces - 1 */
		UAC_ControlInterface_Intfc_1,   /* Audio Streaming interface 1 belongs to this AudioControl Interface */

		/* Input terminal descriptor */
		0x0C,                           /* Descriptor size in bytes */
		0x24,                           /* CS Interface Descriptor */
		0x02,                           /* Input Terminal Descriptor subtype */
		0x05,                           /* ID Of the input terminal */
		0x01, 0x01,                     /* USB Streaming - terminal type */
		0x00,                           /* Association terminal - None */
		0x02,                           /* Number of channels - 2 */
		0x03, 0x00,                     /* spatial location of the logical channels - Front Left and Front Right */
		0x00,                           /* Channel names - Unused */
		0x00,                           /* String index for this descriptor - None */

		/* Output terminal descriptor */
		0x09,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x03,                           /* Output terminal descriptor type */
		0x06,                           /* ID of this terminal */
		0x01, 0x03,                     /* Output terminal type: Speaker */
		0x00,                           /* Association terminal - Unused */
		0x05,                           /* Id of the terminal/unit to which this is connected - Input terminal id */
		0x00,                           /* String desc index : Not used */

		/* Standard Audio Streaming Interface Descriptor (Alternate setting 0) */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		UAC_ControlInterface_Intfc_1,   /* Interface number */
		0x00,                           /* Alternate setting number */
		0x00,                           /* Number of end points : zero bandwidth */
		0x01,                           /* Interface class : Audio */
		0x02,                           /* Interface sub class : Audio Streaming */
		0x00,                           /* Interface protocol code : Unused */
		0x00,                           /* Interface descriptor string index */

		/* Standard Audio Streaming Interface descriptor (Alternate setting 1) */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		UAC_ControlInterface_Intfc_1,   /* Interface number */
		0x01,                           /* Alternate setting number */
		0x01,                           /* Number of end points : 1 ISO EP */
		0x01,                           /* Interface Audio class */
		0x02,                           /* Interface Audio sub class - Audio Streaming */
		0x00,                           /* Interface protocol code : Unused */
		0x00,                           /* Interface descriptor string index */

		/* Class-specific Audio Streaming General Interface descriptor */
		0x07,                           /* Descriptor size */
		0x24,                           /* Class-specific AS i/f Type */
		0x01,                           /* Descriptotor subtype : AS General */
		0x05,                           /* Terminal Link - input terminal id */
		0x01,                           /* Interface delay */
		0x02, 0x00,                     /* Audio data format - PCM */

		/* Class specific AS Format descriptor - Type I Format Descriptor */
		0x0B,                           /* Descriptor size */
		0x24,                           /* Class-specific Interface Descriptor Type */
		0x02,                           /* Format Type Descriptor subtype */
		0x01,                           /* PCM FORMAT_TYPE_I */
		0x02,                           /* Number of channels - 2 */
		0x03,                           /* Subframe size - 8 bytes per audio subframe */
		0x18,                           /* Bit resolution - 24 bits */
		0x01,                           /* Number of samping frequencies - 1 */
		0x80, 0xBB, 0x00,               /* Sampling frequency - 48kHz */

		/* Endpoint descriptor for ISO streaming Audio data */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
		UAC_EndPoint_0,					/* Endpoint address and description */
		CY_U3P_USB_EP_ISO ,				/* ISO End point : Async */
		0xD0, 0x02,						/* Transaction size - 3*2*49 bytes per frame */
		0x03,                           /* Servicing interval for data transfers */
		0x00,							/* bRefresh */
		0x00,							/* bSynchAddress */

		/* Class Specific AS Isochronous Audio Data Endpoint Descriptor */
		0x07,                           /* Descriptor size in bytes */
		0x25,                           /* CS_ENDPOINT descriptor type */
		0x01,                           /* EP_GENERAL sub-descriptor type */
		0x00,                           /* bmAttributes - Max packets only */
		0x00,                           /* bLockDelayUnits - Unused */
		0x00, 0x00,                     /* wLockDelay - unused */
#endif


#if 1
		/*Total = 0x63*/
		/*Interface Association Descriptor*/
		0x08,                               /* bLength */
		ES_UVC_INTRFC_ASSN_DESCR,           /* bDescriptorType */
		UAC_ControlInterface_Intfc_2,       /* bFirstInterface */
		0x02,                               /* bInterfaceCount */
		0x01,                               /* bFunctionClass */
		0x03,                               /* bFunctionSubClass */
		0x00,                               /* bFunctionProtocol */
		0x00,                               /* iFunction */

		/* Standard Audio Control Interface Descriptor */
		0x09,                           /* Descriptor Size */
		0x04,                           /* Interface Descriptor Type */
		UAC_ControlInterface_Intfc_2,   /* Interface number */
		0x00,                           /* Alternate setting */
		0x00,                           /* Number of endpoints - 0 endpoints */
		0x01,                           /* Interface Class - Audio */
		0x01,                           /* Interface SubClass - Audio Control */
		0x00,                           /* Interface Protocol - Unused */
		0x00,                           /* Interface string index */

		/* Class Specific Audio Control Interface Descriptor */
		0x09,                           /* Descriptor Size */
		0x24,                           /* Descriptor Type - CS_INTERFACE */
		0x01,                           /* Descriptor SubType - Header */
		0x00, 0x01,                     /* Revision of class specification - 1.0 */
		0x1E, 0x00,                     /* Total size of class specific descriptors */
		0x01,                           /* Number of streaming Interfaces - 1 */
		UAC_ControlInterface_Intfc_3,   /* Audio Streaming interface 3 belongs to this AudioControl Interface */

		/* Input terminal descriptor */
		0x0C,                           /* Descriptor size in bytes */
		0x24,                           /* CS Interface Descriptor */
		0x02,                           /* Input Terminal Descriptor subtype */
		0x03,                           /* ID Of the input terminal */
		0x01, 0x02,                     /* Microphone - terminal type */
		0x00,                           /* Association terminal - None */
		0x02,                           /* Number of channels - 2 */
		0x03, 0x00,                     /* spatial location of the logical channels - Front Left and Front Right */
		0x00,                           /* Channel names - Unused */
		0x00,                           /* String index for this descriptor - None */

		/* Output terminal descriptor */
		0x09,                           /* Descriptor size */
		0x24,                           /* Class specific interface desc type */
		0x03,                           /* Output terminal descriptor type */
		0x04,                           /* ID of this terminal */
		0x01, 0x01,                     /* Output terminal type: USB Streaming */
		0x00,                           /* Association terminal - Unused */
		0x03,                           /* Id of the terminal/unit to which this is connected - Input terminal id */
		0x00,                           /* String desc index : Not used */

		/* Standard Audio Streaming Interface Descriptor (Alternate setting 0) */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		UAC_ControlInterface_Intfc_3,   /* Interface number */
		0x00,                           /* Alternate setting number */
		0x00,                           /* Number of end points : zero bandwidth */
		0x01,                           /* Interface class : Audio */
		0x02,                           /* Interface sub class : Audio Streaming */
		0x00,                           /* Interface protocol code : Unused */
		0x00,                           /* Interface descriptor string index */

		/* Standard Audio Streaming Interface descriptor (Alternate setting 1) */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_INTRFC_DESCR,        /* Interface descriptor type */
		UAC_ControlInterface_Intfc_3,   /* Interface number */
		0x01,                           /* Alternate setting number */
		0x01,                           /* Number of end points : 1 ISO EP */
		0x01,                           /* Interface Audio class */
		0x02,                           /* Interface Audio sub class - Audio Streaming */
		0x00,                           /* Interface protocol code : Unused */
		0x00,                           /* Interface descriptor string index */

		/* Class-specific Audio Streaming General Interface descriptor */
		0x07,                           /* Descriptor size */
		0x24,                           /* Class-specific AS i/f Type */
		0x01,                           /* Descriptotor subtype : AS General */
		0x04,                           /* Terminal Link - Output terminal id */
		0x01,                           /* Interface delay */
		0x01, 0x00,                     /* Audio data format - PCM */

		/* Class specific AS Format descriptor - Type I Format Descriptor */
		0x0B,                           /* Descriptor size */
		0x24,                           /* Class-specific Interface Descriptor Type */
		0x02,                           /* Format Type Descriptor subtype */
		0x01,                           /* PCM FORMAT_TYPE_I */
		0x02,                           /* Number of channels - 2 */
		0x02,                           /* Subframe size - 2 bytes per audio subframe */
		0x10,                           /* Bit resolution - 16 bits */
		0x01,                           /* Number of samping frequencies - 1 */
		0x80, 0xBB, 0x00,               /* Sampling frequency - 48000 Hz */

		/* Endpoint descriptor for ISO streaming Audio data */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_ENDPNT_DESCR,        /* Endpoint descriptor type */
		UAC_EndPoint_1,                 /* Endpoint address and description */
		0x05,                           /* ISO End point : Async */
		0x60, 0x00,                     /* Transaction size - 96 bytes per frame */
		0x03,                           /* Servicing interval for data transfers */
		0x00,                           /* bRefresh */
		0x00,                           /* bSynchAddress */

		/* Class Specific AS Isochronous Audio Data Endpoint Descriptor */
		0x07,                           /* Descriptor size in bytes */
		0x25,                           /* CS_ENDPOINT descriptor type */
		0x01,                           /* EP_GENERAL sub-descriptor type */
		0x00,                           /* bmAttributes - None  */
		0x00,                           /* bLockDelayUnits - Unused */
		0x00, 0x00                      /* wLockDelay - unused */

	#endif

};


/* Standard full speed configuration descriptor : full speed is not supported. */
const uint8_t CyFxUSBFSConfigDscr[] __attribute__ ((aligned (32))) =
{
		/* Configuration descriptor */
		0x09,                           /* Descriptor size */
		CY_U3P_USB_CONFIG_DESCR,        /* Configuration descriptor type */
		0x09,0x00,                      /* Length of this descriptor and all sub descriptors */
		0x00,                           /* Number of interfaces */
		0x01,                           /* Configuration number */
		0x00,                           /* COnfiguration string index */
		0x80,                           /* Config characteristics - bus powered */
		0x32,                           /* Max power consumption of device (in 2mA unit) : 100mA */
};

/* Standard language ID string descriptor */
const uint8_t CyFxUSBStringLangIDDscr[] __attribute__ ((aligned (32))) =
{
		0x04,                           /* Descriptor size */
		CY_U3P_USB_STRING_DESCR,        /* Device descriptor type */
		0x09,0x04                       /* Language ID supported */
};

/* Standard manufacturer string descriptor */
const uint8_t CyFxUSBManufactureDscr[] __attribute__ ((aligned (32))) =
{
		0x10,                           /* Descriptor size */
		CY_U3P_USB_STRING_DESCR,        /* Device descriptor type */
		'C',0x00,
		'y',0x00,
		'p',0x00,
		'r',0x00,
		'e',0x00,
		's',0x00,
		's',0x00
};

/* Standard product string descriptor */
const uint8_t CyFxUSBProductDscr[] __attribute__ ((aligned (32))) =
{
		0x08,                           /* Descriptor Size */
		CY_U3P_USB_STRING_DESCR,        /* Device descriptor type */
		'F',0x00,
		'X',0x00,
		'3',0x00
};

/* Place this buffer as the last buffer so that no other variable / code shares
 * the same cache line. Do not add any other variables / arrays in this file.
 * This will lead to variables sharing the same cache line. */
const uint8_t CyFxUsbDscrAlignBuffer[32] __attribute__ ((aligned (32)));

/* [ ] */

